@@ -1,12 +1,12 @@
-from typing import Optional, Union
+from typing import Optional, Sequence, Union
 
 from libcst import (
     Arg,
-    Attribute,
     BaseExpression,
     BaseSmallStatement,
     BaseStatement,
     Call,
+    FlattenSentinel,
     FunctionDef,
     ImportFrom,
     ImportStar,
@@ -19,9 +19,20 @@ from libcst import (
 from libcst import matchers as m
 from libcst.codemod.visitors import AddImportsVisitor
 
-from django_codemod.constants import DJANGO_1_9, DJANGO_1_11, DJANGO_2_0, DJANGO_2_1
-from django_codemod.utils.calls import find_keyword_arg
-from django_codemod.visitors.base import BaseDjCodemodTransformer, module_matcher
+from django_codemod.constants import (
+    DJANGO_1_9,
+    DJANGO_1_11,
+    DJANGO_2_0,
+    DJANGO_2_1,
+    DJANGO_3_1,
+    DJANGO_4_0,
+)
+from django_codemod.utils.calls import find_keyword_arg, make_kwarg
+from django_codemod.visitors.base import (
+    BaseDjCodemodTransformer,
+    BaseFuncRenameTransformer,
+    module_matcher,
+)
 
 
 class ModelsPermalinkTransformer(BaseDjCodemodTransformer):
@@ -35,7 +46,9 @@ class ModelsPermalinkTransformer(BaseDjCodemodTransformer):
 
     def leave_ImportFrom(
         self, original_node: ImportFrom, updated_node: ImportFrom
-    ) -> Union[BaseSmallStatement, RemovalSentinel]:
+    ) -> Union[
+        BaseSmallStatement, FlattenSentinel[BaseSmallStatement], RemovalSentinel
+    ]:
         if isinstance(updated_node.names, ImportStar):
             return super().leave_ImportFrom(original_node, updated_node)
         if m.matches(
@@ -99,7 +112,7 @@ class ModelsPermalinkTransformer(BaseDjCodemodTransformer):
 
     def leave_FunctionDef(
         self, original_node: FunctionDef, updated_node: FunctionDef
-    ) -> Union[BaseStatement, RemovalSentinel]:
+    ) -> Union[BaseStatement, FlattenSentinel[BaseStatement], RemovalSentinel]:
         if self.visiting_permalink_method:
             for decorator in updated_node.decorators:
                 if m.matches(decorator, self.decorator_matcher):
@@ -122,7 +135,9 @@ class ModelsPermalinkTransformer(BaseDjCodemodTransformer):
 
     def leave_Return(
         self, original_node: Return, updated_node: Return
-    ) -> Union[BaseSmallStatement, RemovalSentinel]:
+    ) -> Union[
+        BaseSmallStatement, FlattenSentinel[BaseSmallStatement], RemovalSentinel
+    ]:
         if self.visiting_permalink_method and m.matches(
             updated_node.value, m.Tuple()  # type: ignore
         ):
@@ -178,10 +193,23 @@ class OnDeleteTransformer(BaseDjCodemodTransformer):
             )
             updated_args = (
                 *updated_node.args,
-                Arg(
-                    keyword=Name("on_delete"),
-                    value=Attribute(value=Name("models"), attr=Name("CASCADE")),
-                ),
+                make_kwarg("on_delete=models.CASCADE"),
             )
             return updated_node.with_changes(args=updated_args)
         return super().leave_Call(original_node, updated_node)
+
+
+class NullBooleanFieldTransformer(BaseFuncRenameTransformer):
+    """Replace `NullBooleanField` by `BooleanField` with `null=True`."""
+
+    deprecated_in = DJANGO_3_1
+    removed_in = DJANGO_4_0
+
+    rename_from = "django.db.models.NullBooleanField"
+    rename_to = "django.db.models.BooleanField"
+
+    def update_call_args(self, node: Call) -> Sequence[Arg]:
+        return (
+            *node.args,
+            make_kwarg("null=True"),
+        )
